@@ -137,15 +137,15 @@ def main(args, fixed=True):
 
     ECL_FLAG = False
 
-    A_eph = EPH.Ephemeris(join(dirname(abspath(__file__)), "horizons_EM_jwst_wrt_sun_2020-2024.txt"),ECL_FLAG, verbose=args.no_verbose)
+    A_eph = EPH.Ephemeris(join(dirname(abspath(__file__)), "horizons_EM_jwst_wrt_sun_2021-2024.txt"),ECL_FLAG, verbose=args.no_verbose)
 
-    search_start = Time(args.start_date, format='iso').mjd if args.start_date is not None else 58849.0  #Jan 1, 2020
-    search_end = Time(args.end_date, format='iso').mjd if args.end_date is not None else 60309.0 # Dec 31, 2023
+    search_start = Time(args.start_date, format='iso').mjd if args.start_date is not None else 59574.0  #Dec 26, 2021
+    search_end = Time(args.end_date, format='iso').mjd if args.end_date is not None else 60585.0  #Oct 02, 2024
 
-    if not (58849.0 <= search_start <= 60309.0) and args.start_date is not None:
-        raise ValueError('Start date {} outside of available ephemeris {} to {}'.format(args.start_date, '2020-01-01', '2023-12-31'))
-    if not (58849.0 <= search_end <= 60309.0) and args.end_date is not None:
-        raise ValueError('End date {} outside of available ephemeris {} to {}'.format(args.end_date, '2020-01-01', '2023-12-31'))
+    if not (59574.0 <= search_start <= 60586.0) and args.start_date is not None:
+        raise ValueError('Start date {} outside of available ephemeris {} to {}'.format(args.start_date, '2021-12-26', '2024-10-02'))
+    if not (59574.0 <= search_end <= 60586.0) and args.end_date is not None:
+        raise ValueError('End date {} outside of available ephemeris {} to {}'.format(args.end_date, '2021-12-26', '2024-10-02'))
     if search_start > search_end:
         raise ValueError('Start date {} should be before end date {}'.format(args.start_date, args.end_date))
 
@@ -561,15 +561,15 @@ def get_table(ra, dec, instrument=None, start_date=None, end_date=None, save_tab
 
     ECL_FLAG = False
 
-    A_eph = EPH.Ephemeris(join(dirname(abspath(__file__)), "horizons_EM_jwst_wrt_sun_2020-2024.txt"),ECL_FLAG, verbose=verbose)
+    A_eph = EPH.Ephemeris(join(dirname(abspath(__file__)), "horizons_EM_jwst_wrt_sun_2021-2024.txt"),ECL_FLAG, verbose=verbose)
 
-    search_start = Time(start_date, format='iso').mjd if start_date is not None else 58849.0  #Jan 1, 2020
-    search_end = Time(end_date, format='iso').mjd if end_date is not None else 60309.0 # Dec 31, 2023
+    search_start = Time(start_date, format='iso').mjd if start_date is not None else 59574.0  #Dec 26, 2021
+    search_end = Time(end_date, format='iso').mjd if end_date is not None else 60585.0  #Oct 02, 2024
 
-    if not (58849.0 <= search_start <= 60309.0) and start_date is not None:
-        raise ValueError('Start date {} outside of available ephemeris {} to {}'.format(start_date, '2020-01-01', '2023-12-31'))
-    if not (58849.0 <= search_end <= 60309.0) and end_date is not None:
-        raise ValueError('End date {} outside of available ephemeris {} to {}'.format(end_date, '2020-01-01', '2023-12-31'))
+    if not (59574.0 <= search_start <= 60586.0) and start_date is not None:
+        raise ValueError('Start date {} outside of available ephemeris {} to {}'.format(start_date, '2021-12-26', '2024-10-02'))
+    if not (59574.0 <= search_end <= 60586.0) and end_date is not None:
+        raise ValueError('End date {} outside of available ephemeris {} to {}'.format(end_date, '2021-12-26', '2024-10-02'))
     if search_start > search_end:
         raise ValueError('Start date {} should be before end date {}'.format(start_date, end_date))
 
